@@ -41,7 +41,24 @@ typedef enum
 	DEV_N810,
 	DEV_BEAGLEBOARD,
 	DEV_HW_SKEYEPADPOS,
-	DEV_TOPAS,
+	DEV_TOPAS910,
+	DEV_MINI2440,
+	DEV_TOPASA900,
+	DEV_AT91SAM9261,
+	DEV_AT91SAM9263,
+	DEV_AT91SAM9RL,
+	DEV_AT91SAM9G10,
+	DEV_AT91SAM9G45,
+	DEV_AT91SAM9M10,
+	DEV_ARCHOS7_A7,
+	DEV_ARCHOS7_S,
+	DEV_ARCHOS7_H,
+	DEV_ARCHOS7_3G,
+	DEV_ARCHOS5_S,
+	DEV_ARCHOS5_H,
+	DEV_KARO_TX25,
+	DEV_KARO_TX27,
+	DEV_KARO_TX51,
 	DEV_MAX
 } DeviceID_t;
 
