@@ -3,7 +3,7 @@
  *              that either displays or sets the characteristics of
  *              one or more of the system's networking interfaces.
  *
- * Version:     $Id: interface.c,v 1.10 2004/09/10 23:22:29 florian Exp $
+ * Version:     $Id: interface.c 7800 2005-10-27 14:54:19Z florian $
  *
  * Author:      Fred N. van Kempen, <waltje@uwalt.nl.mugnet.org>
  *              and others.  Copyright 1993 MicroWalt Corporation
@@ -1868,7 +1868,14 @@ char* if_to_infostr(struct interface *ptr)
     if (hw == NULL)
 	hw = get_hwntype(-1);
 
-    sprintf(tmp,_("<b>Interface %s</b>\nType: %s\n"), ptr->name, _(hw->title));
+    {
+      char s[256], t[256];
+      
+      sprintf(s, "%s%s %s%s", _("Interface:"), "<span foreground=\"blue\">", ptr->name, "</span>");
+      sprintf(t, _("Type: %s"), _(hw->title));
+      sprintf(tmp, "<span size=\"large\">%s</span>\n%s\n", s, t);
+    }
+
 	buffer = realloc(buffer,strlen(buffer)+strlen(tmp)+1);
 	strcat(buffer,tmp);
 	
